==> haskell-tar-conduit-0.4.1-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-J8elb9X26aFIglEBg91h9I
key:                  tar-conduit-0.4.1-J8elb9X26aFIglEBg91h9I
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  68a8591c3ceb99b1831f8d26c1158e3e
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-J8elb9X26aFIglEBg91h9I
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx text-1.2.5.0
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.4.1-37-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-20mOsnRrcVG8cOntV4mUy1
key:                  tar-conduit-0.4.1-20mOsnRrcVG8cOntV4mUy1
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  957e9c1f681f984bcccc58f72ad4de7a
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-20mOsnRrcVG8cOntV4mUy1
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx text-1.2.5.0
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
